Module remote

Module remote 

Remote registry client for Pacha

Provides HTTP client for interacting with remote Pacha registries. This module requires the remote feature to be enabled.

Example

use pacha::remote::{RemoteRegistry, RegistryAuth};

let registry = RemoteRegistry::new("https://registry.example.com")
    .with_auth(RegistryAuth::Token("my-token".to_string()));

// Pull a model
let model = registry.pull_model("llama3", "1.0.0").await?;

// List available models
let models = registry.list_models().await?;

Structs

LineageInfo
Lineage information from remote registry
ListModelsResponse
Remote registry API response for listing models
ListVersionsResponse
Remote registry API response for listing versions
ModelMetadataResponse
Remote registry API response for model metadata
PushRequest
Push request body
PushResponse
Push response
RemoteRegistry
Remote registry client
VersionInfo
Version information

Enums

RegistryAuth
Authentication configuration

Functions

pull_to_local
Pull a model from remote registry and optionally cache locally
push_to_remote
Push a local model to remote registry