Remote registry client for Pacha
Provides HTTP client for interacting with remote Pacha registries.
This module requires the remote feature to be enabled.
Example
use pacha::remote::{RemoteRegistry, RegistryAuth};
let registry = RemoteRegistry::new("https://registry.example.com")
.with_auth(RegistryAuth::Token("my-token".to_string()));
// Pull a model
let model = registry.pull_model("llama3", "1.0.0").await?;
// List available models
let models = registry.list_models().await?;Structs
- Lineage
Info - Lineage information from remote registry
- List
Models Response - Remote registry API response for listing models
- List
Versions Response - Remote registry API response for listing versions
- Model
Metadata Response - Remote registry API response for model metadata
- Push
Request - Push request body
- Push
Response - Push response
- Remote
Registry - Remote registry client
- Version
Info - Version information
Enums
- Registry
Auth - Authentication configuration
Functions
- pull_
to_ local - Pull a model from remote registry and optionally cache locally
- push_
to_ remote - Push a local model to remote registry